==> aliyun-python-sdk-core-2.13.30.tar.gz: aliyun-python-sdk-core-2.13.30/aliyunsdkcore/utils/parameter_helper.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# coding=utf-8

import hashlib
import base64
import socket
import uuid
import time
import xml.etree.cElementTree as EleTree

from aliyunsdkcore.compat import ensure_bytes, ensure_string

TIME_ZONE = "GMT"
FORMAT_ISO_8601 = "%Y-%m-%dT%H:%M:%SZ"
FORMAT_RFC_2616 = "%a, %d %b %Y %H:%M:%S GMT"


def get_uuid():
    name = socket.gethostname() + str(uuid.uuid1())
    namespace = uuid.NAMESPACE_URL
    return str(uuid.uuid5(namespace, name))


def get_iso_8061_date():
    return time.strftime(FORMAT_ISO_8601, time.gmtime())


def get_rfc_2616_date():
    return time.strftime(FORMAT_RFC_2616, time.gmtime())


def md5_sum(content):
    content_bytes = ensure_bytes(content)
    md5_bytes = hashlib.md5(content_bytes).digest()
    return ensure_string(base64.standard_b64encode(md5_bytes))


def _get_xml_by_list(elem, val, parent_element):
    i = 0
    tag_name = elem.tag
    if val.__len__() > 0:
        _get_xml_factory(elem, val[0], parent_element)

    for item in val:
        if i > 0:
            sub_elem = EleTree.SubElement(parent_element, tag_name)
            _get_xml_factory(sub_elem, item, parent_element)
        i = i + 1


def _get_xml_by_dict(elem, val):
    for k in val:
        sub_elem = EleTree.SubElement(elem, k)
        _get_xml_factory(sub_elem, val[k], elem)


def _get_xml_factory(elem, val, parent_element=None):
    if val is None:
        return

    if isinstance(val, dict):
        _get_xml_by_dict(elem, val)
    elif isinstance(val, (list, tuple, set)):
        if parent_element is None:
            raise ValueError("parent_element")
        _get_xml_by_list(elem, val, parent_element)
    else:
        elem.text = str(val)


def to_xml(dic):
    if dic is None:
        return

    if dic.__len__() == 0:
        return ""
    else:
        result_xml = ""
        for k in dic:
            elem = EleTree.Element(k)
            _get_xml_factory(elem, dic[k])
            result_xml += bytes.decode(EleTree.tostring(elem), encoding="utf-8")
        return result_xml

==> aliyun-python-sdk-core-v3-2.5.1.tar.gz: aliyun-python-sdk-core-v3-2.5.1/aliyunsdkcore/utils/parameter_helper.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

# coding=utf-8

import hashlib
import base64
import uuid
import time
import urllib
import sys

TIME_ZONE = "GMT"
FORMAT_ISO_8601 = "%Y-%m-%dT%H:%M:%SZ"
FORMAT_RFC_2616 = "%a, %d %b %Y %X GMT"


def get_uuid():
    return str(uuid.uuid4())


def get_iso_8061_date():
    return time.strftime(FORMAT_ISO_8601, time.gmtime())


def get_rfc_2616_date():
    return time.strftime(FORMAT_RFC_2616, time.gmtime())


def md5_sum(content):
    content_bytes = bytearray(content, "utf-8")
    md5_bytes = hashlib.md5(content_bytes).digest()
    return base64.standard_b64encode(md5_bytes)


def percent_encode(encodeStr):
    encodeStr = str(encodeStr)
    if sys.stdin.encoding is None:
        res = urllib.parse.quote(encodeStr.decode('cp936').encode('utf8'), '')
    else:
        res = urllib.parse.quote(
            encodeStr.decode(
                sys.stdin.encoding).encode('utf8'), '')
    res = res.replace('+', '%20')
    res = res.replace('*', '%2A')
    res = res.replace('%7E', '~')
    return res


if __name__ == "__main__":
    print(get_uuid())
    print(get_iso_8061_date())
    print(get_rfc_2616_date())
